package Catalyst::Plugin::Memory;
use strict;
use warnings;
use Carp qw(croak carp);

our $VERSION = '0.01';

=head1 NAME

Catalyst::Plugin::Memory - Temporarily store data for the time of a request

=head1 SYNPOSIS

  use Catalyst qw(Memory);

  # ... chain usage ...

  sub pick :Chained('/thing') :PathPart('') :CaptureArgs(1)
  {
    my ($self, $c, $thing) = @_;

    $c->memory->{'thing'} = $thing;
  }

  sub detail :Chained('pick') :PathPart('detail') :Args(0)
  {
    my ($self, $c) = @_;
    my $thing = $c->memory->{'thing'};

    # ...

    $c->forward('foo');

    # ...
  }

  # ... access in forwarded method ...

  sub foo :Private
  {
    my ($self, $c) = @_;
    my() $thing = $c->memory->{'thing'};

    # ...
  }

=head1 METHODS

=head2 prepare

=cut

sub prepare {
	my $class = shift;
	my $self = $class->NEXT::prepare(@_);

	$self->{'memory'} = {};

	return $self;
}

=head2 memory

=cut

sub memory {
	my $c = shift;

	if (@_) {
		my $memory = @_ > 1 ? {@_} : $_[0];

		croak('memory takes a hash or hashref') unless ref $memory;

		foreach my $key ( keys %$memory ) {
			$c->{'memory'}{$key} = $memory->{$key};
		}
	}

	return $c->{'memory'};
}

=head1 SEE ALSO

=over 4

=item L<Catalyst::Runtime>

=back

=head1 AUTHOR

Simon Bertrang E<lt>simon.bertrang@puzzworks.comE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2008 by PuzzWorks, OHG.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
